==> amarok-2.3.0.90.tar.bz2: amarok-2.3.0.90/src/core-impl/playlists/providers/user/UserPlaylistProvider.h <==
/****************************************************************************************
 * Copyright (c) 2008 Nikolaj Hald Nielsen <nhn@kde.org>                                *
 * Copyright (c) 2008 Bart Cerneels <bart.cerneels@kde.org>                             *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef USERPLAYLISTPROVIDER_H
#define USERPLAYLISTPROVIDER_H

#include "core/playlists/Playlist.h"
#include "core/playlists/PlaylistProvider.h"

class QAction;

namespace Playlists {

/**
    @author Bart Cerneels <bart.cerneels@kde.org>
*/
class AMAROK_EXPORT UserPlaylistProvider : public PlaylistProvider
{
    Q_OBJECT
    public:
        virtual ~UserPlaylistProvider();

        /* PlaylistProvider functions */
        virtual int category() const;

        /* UserPlaylistProvider functions */
        /**
            @returns true if this provider supports - and is currently able to - save playlists
        **/
        virtual bool canSavePlaylists() = 0;

        /**
            Save a list of tracks as a playlist in the database.
            @returns a non-null Playlists::PlaylistPtr if successful
        **/
        virtual Playlists::PlaylistPtr save( const Meta::TrackList &tracks ) = 0;

        virtual Playlists::PlaylistPtr save( const Meta::TrackList &tracks, const QString& name ) = 0;

        virtual bool supportsEmptyGroups();

        virtual QList<QAction *> playlistActions( Playlists::PlaylistPtr playlist );
        virtual QList<QAction *> trackActions( Playlists::PlaylistPtr playlist,
                                                  int trackIndex );

        // UserPlaylistProvider-specific

        virtual bool isWritable() { return false; }
        virtual void rename( Playlists::PlaylistPtr playlist, const QString &newName ) {Q_UNUSED( playlist ) Q_UNUSED(newName)}
        virtual void deletePlaylists( Playlists::PlaylistList playlistlist ) { Q_UNUSED( playlistlist ) }

    signals:
            void updated();
};

} //namespace Playlists

#endif

==> amarok-2.3.1.90.tar.bz2: amarok-2.3.1.90/src/core-impl/playlists/providers/user/UserPlaylistProvider.h <==
/****************************************************************************************
 * Copyright (c) 2008 Nikolaj Hald Nielsen <nhn@kde.org>                                *
 * Copyright (c) 2008 Bart Cerneels <bart.cerneels@kde.org>                             *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef USERPLAYLISTPROVIDER_H
#define USERPLAYLISTPROVIDER_H

#include "core/playlists/Playlist.h"
#include "core/playlists/PlaylistProvider.h"

class QAction;

namespace Playlists {

/**
    @author Bart Cerneels <bart.cerneels@kde.org>
*/
class AMAROK_EXPORT UserPlaylistProvider : public PlaylistProvider
{
    Q_OBJECT
    public:
        virtual ~UserPlaylistProvider();

        /* PlaylistProvider functions */
        virtual int category() const;

        /* UserPlaylistProvider functions */
        /**
            @returns true if this provider supports - and is currently able to - save playlists
        **/
        virtual bool canSavePlaylists() = 0;

        /**
            Save a list of tracks as a playlist in the database.
            @returns a non-null Playlists::PlaylistPtr if successful
        **/
        virtual Playlists::PlaylistPtr save( const Meta::TrackList &tracks ) = 0;

        virtual Playlists::PlaylistPtr save( const Meta::TrackList &tracks, const QString& name ) = 0;

        virtual bool supportsEmptyGroups();

        virtual QList<QAction *> playlistActions( Playlists::PlaylistPtr playlist );
        virtual QList<QAction *> trackActions( Playlists::PlaylistPtr playlist,
                                                  int trackIndex );

        // UserPlaylistProvider-specific
        virtual bool isWritable() { return false; }
        virtual void rename( Playlists::PlaylistPtr playlist, const QString &newName )
                { Q_UNUSED( playlist ) Q_UNUSED(newName) }
        virtual bool deletePlaylists( Playlists::PlaylistList playlistlist )
                { Q_UNUSED( playlistlist ) return false; }

    signals:
            void updated();
};

} //namespace Playlists

#endif
